==> activity-center-api-0.9.22-20190626.084529-45-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/CreditsOrienteeringDetailDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import io.swagger.models.auth.In;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: CreditsOrienteeringDetailDto <br/>
 * Function: 定向配置详情dto. <br/>
 * Reason: . <br/>
 * date: 2019年6月24日 上午10:46:51 <br/>
 *
 * @author scd
 * @version
 * @since JDK 1.8
 */
public class CreditsOrienteeringDetailDto extends BaseDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;
    private String title;
    private Integer mediaSwitch; //媒体定向开关
    private Integer slotSwitch;//广告位定向开关
    private Integer activitySwitch;//活动定向开关

    private List<CreditsOrienteerDto> mediaList;//媒体集合
    private List<CreditsOrienteerDto> slotList;//广告位集合
    private List<CreditsOrienteerDto> activityList;//活动集合

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getMediaSwitch() {
        return mediaSwitch;
    }

    public void setMediaSwitch(Integer mediaSwitch) {
        this.mediaSwitch = mediaSwitch;
    }

    public Integer getSlotSwitch() {
        return slotSwitch;
    }

    public void setSlotSwitch(Integer slotSwitch) {
        this.slotSwitch = slotSwitch;
    }

    public Integer getActivitySwitch() {
        return activitySwitch;
    }

    public void setActivitySwitch(Integer activitySwitch) {
        this.activitySwitch = activitySwitch;
    }

    public List<CreditsOrienteerDto> getMediaList() {
        return mediaList;
    }

    public void setMediaList(List<CreditsOrienteerDto> mediaList) {
        this.mediaList = mediaList;
    }

    public List<CreditsOrienteerDto> getSlotList() {
        return slotList;
    }

    public void setSlotList(List<CreditsOrienteerDto> slotList) {
        this.slotList = slotList;
    }

    public List<CreditsOrienteerDto> getActivityList() {
        return activityList;
    }

    public void setActivityList(List<CreditsOrienteerDto> activityList) {
        this.activityList = activityList;
    }
}

==> activity-center-api-0.9.22-20190627.052739-57-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/CreditsOrienteeringDetailDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;
import io.swagger.models.auth.In;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: CreditsOrienteeringDetailDto <br/>
 * Function: 定向配置详情dto. <br/>
 * Reason: . <br/>
 * date: 2019年6月24日 上午10:46:51 <br/>
 *
 * @author scd
 * @version
 * @since JDK 1.8
 */
public class CreditsOrienteeringDetailDto extends BaseDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;
    private String title;
    private Integer mediaSwitch; //媒体定向开关
    private Integer slotSwitch;//广告位定向开关
    private Integer activitySwitch;//活动定向开关

    private List<CreditsOrienteerDto> mediaList;//媒体集合
    private List<CreditsOrienteerDto> slotList;//广告位集合
    private List<CreditsOrienteerDto> activityList;//活动集合

    private String msg;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getMediaSwitch() {
        return mediaSwitch;
    }

    public void setMediaSwitch(Integer mediaSwitch) {
        this.mediaSwitch = mediaSwitch;
    }

    public Integer getSlotSwitch() {
        return slotSwitch;
    }

    public void setSlotSwitch(Integer slotSwitch) {
        this.slotSwitch = slotSwitch;
    }

    public Integer getActivitySwitch() {
        return activitySwitch;
    }

    public void setActivitySwitch(Integer activitySwitch) {
        this.activitySwitch = activitySwitch;
    }

    public List<CreditsOrienteerDto> getMediaList() {
        return mediaList;
    }

    public void setMediaList(List<CreditsOrienteerDto> mediaList) {
        this.mediaList = mediaList;
    }

    public List<CreditsOrienteerDto> getSlotList() {
        return slotList;
    }

    public void setSlotList(List<CreditsOrienteerDto> slotList) {
        this.slotList = slotList;
    }

    public List<CreditsOrienteerDto> getActivityList() {
        return activityList;
    }

    public void setActivityList(List<CreditsOrienteerDto> activityList) {
        this.activityList = activityList;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }
}
